Module beamlit.models.billing_address
=====================================

Classes
-------

`BillingAddress(city: beamlit.types.Unset | str = <beamlit.types.Unset object>, country: beamlit.types.Unset | str = <beamlit.types.Unset object>, first_name: beamlit.types.Unset | str = <beamlit.types.Unset object>, last_name: beamlit.types.Unset | str = <beamlit.types.Unset object>, phone_number: beamlit.types.Unset | str = <beamlit.types.Unset object>, postal_code: beamlit.types.Unset | str = <beamlit.types.Unset object>, state: beamlit.types.Unset | str = <beamlit.types.Unset object>, street1: beamlit.types.Unset | str = <beamlit.types.Unset object>, street2: beamlit.types.Unset | str = <beamlit.types.Unset object>)`
:   BillingAddress
    
    Attributes:
        city (Union[Unset, str]): City
        country (Union[Unset, str]): Country
        first_name (Union[Unset, str]): First name
        last_name (Union[Unset, str]): Last name
        phone_number (Union[Unset, str]): Phone number
        postal_code (Union[Unset, str]): Postal code
        state (Union[Unset, str]): State/Province/Region
        street1 (Union[Unset, str]): Street 1
        street2 (Union[Unset, str]): Street 2
    
    Method generated by attrs for class BillingAddress.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `city: beamlit.types.Unset | str`
    :

    `country: beamlit.types.Unset | str`
    :

    `first_name: beamlit.types.Unset | str`
    :

    `last_name: beamlit.types.Unset | str`
    :

    `phone_number: beamlit.types.Unset | str`
    :

    `postal_code: beamlit.types.Unset | str`
    :

    `state: beamlit.types.Unset | str`
    :

    `street1: beamlit.types.Unset | str`
    :

    `street2: beamlit.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :